@@ -12,7 +12,7 @@ Created: Wed Jan 24 20:19:53 1996 ylo
 */
 
 /*
- * $Id: userfile.c,v 1.2 1998/07/10 13:47:22 tri Exp $
+ * $Id: userfile.c,v 1.3 1998/10/08 15:23:29 kivinen Exp $
  * $Log: userfile.c,v $
  * $EndLog$
  */
@@ -23,102 +23,102 @@ Created: Wed Jan 24 20:19:53 1996 ylo
       type but not length itself), followed by one byte containing
       the packet type.
 
-	1 USERFILE_OPEN
-          string 	file name
-	  int32 	flags
-	  int32		mode
+        1 USERFILE_OPEN
+          string        file name
+          int32         flags
+          int32         mode
 
-	2 USERFILE_OPEN_REPLY
-	  int32		handle (-1 if error)
+        2 USERFILE_OPEN_REPLY
+          int32         handle (-1 if error)
 
-	3 USERFILE_READ
-	  int32		handle
-	  int32		max_bytes
+        3 USERFILE_READ
+          int32         handle
+          int32         max_bytes
 
         4 USERFILE_READ_REPLY
-	  string	data	  ;; empty data means EOF
+          string        data      ;; empty data means EOF
 
-	5 USERFILE_WRITE
-	  int32		handle
-	  string	data
+        5 USERFILE_WRITE
+          int32         handle
+          string        data
 
-	6 USERFILE_WRITE_REPLY
-	  int32		bytes_written  ;; != length of data means error
-	
-	7 USERFILE_CLOSE
-	  int32		handle
+        6 USERFILE_WRITE_REPLY
+          int32         bytes_written  ;; != length of data means error
+        
+        7 USERFILE_CLOSE
+          int32         handle
 
-	8 USERFILE_CLOSE_REPLY
-	  int32		return value
+        8 USERFILE_CLOSE_REPLY
+          int32         return value
 
-	9 USERFILE_LSEEK
-	  int32		handle
-	  int32		offset
-	  int32		whence
+        9 USERFILE_LSEEK
+          int32         handle
+          int32         offset
+          int32         whence
 
        10 USERFILE_LSEEK_REPLY
-	  int32 	returned_offset
+          int32         returned_offset
 
        11 USERFILE_MKDIR
-	  string	path
-	  int32		mode
+          string        path
+          int32         mode
 
        12 USERFILE_MKDIR_REPLY
-	  int32		return value
+          int32         return value
 
        13 USERFILE_STAT
-	  string	path
+          string        path
 
        14 USERFILE_STAT_REPLY
-          int32		return value
-	  sizeof(struct stat) binary bytes (in host order and layout)
+          int32         return value
+          sizeof(struct stat) binary bytes (in host order and layout)
 
        15 USERFILE_REMOVE
-	  string	path
+          string        path
 
        16 USERFILE_REMOVE_REPLY
-	  int32		return value
+          int32         return value
 
        17 USERFILE_POPEN
-	  string	command
-	  string	type
+          string        command
+          string        type
 
        18 USERFILE_POPEN_REPLY
-	  int32		handle (-1 if error)
+          int32         handle (-1 if error)
 
        19 USERFILE_PCLOSE
-          int32		handle
+          int32         handle
 
        20 USERFILE_PCLOSE_REPLY
-	  int32		return value
+          int32         return value
 
        21 USERFILE_RENAME
-	  string	oldpath
-	  string	newpath
+          string        oldpath
+          string        newpath
 
        22 USERFILE_RENAME_REPLY
-	  int32		return value
+          int32         return value
 
        23 USERFILE_SHARED_LOCK
           int32         handle
-	  int32         offset
-	  int32         length
+          int32         offset
+          int32         length
 
        24 USERFILE_SHARED_LOCK_REPLY
           int32         return value
-	  
+          
        25 USERFILE_EXCL_LOCK
           int32         handle
-	  int32         offset
-	  int32         length
+          int32         offset
+          int32         length
 
        26 USERFILE_EXCL_LOCK_REPLY
           int32         return value
-	  
+          
        27 USERFILE_UNLOCK
           int32         handle
-	  int32         offset
-	  int32         length
+          int32         offset
+          int32         length
 
        28 USERFILE_UNLOCK_REPLY
           int32         return value
@@ -126,9 +126,9 @@ Created: Wed Jan 24 20:19:53 1996 ylo
        29 USERFILE_GET_DES_1_MAGIC_PHRASE
 
        30 USERFILE_GET_DES_1_MAGIC_PHRASE_REPLY
-	  string	data
-	  
-	  */
+          string        data
+          
+          */
 
 #include "sshincludes.h"
 #include "userfile.h"
@@ -148,27 +148,27 @@ Created: Wed Jan 24 20:19:53 1996 ylo
 #endif
 
 /* Protocol message types. */
-#define USERFILE_OPEN		1
-#define USERFILE_OPEN_REPLY	2
-#define USERFILE_READ		3
-#define USERFILE_READ_REPLY	4
-#define USERFILE_WRITE		5
-#define USERFILE_WRITE_REPLY	6
-#define USERFILE_CLOSE		7
-#define USERFILE_CLOSE_REPLY	8
-#define USERFILE_LSEEK		9
+#define USERFILE_OPEN           1
+#define USERFILE_OPEN_REPLY     2
+#define USERFILE_READ           3
+#define USERFILE_READ_REPLY     4
+#define USERFILE_WRITE          5
+#define USERFILE_WRITE_REPLY    6
+#define USERFILE_CLOSE          7
+#define USERFILE_CLOSE_REPLY    8
+#define USERFILE_LSEEK          9
 #define USERFILE_LSEEK_REPLY   10
-#define USERFILE_MKDIR	       11
+#define USERFILE_MKDIR         11
 #define USERFILE_MKDIR_REPLY   12
-#define USERFILE_STAT	       13
+#define USERFILE_STAT          13
 #define USERFILE_STAT_REPLY    14
-#define USERFILE_REMOVE	       15
+#define USERFILE_REMOVE        15
 #define USERFILE_REMOVE_REPLY  16
-#define USERFILE_POPEN	       17
+#define USERFILE_POPEN         17
 #define USERFILE_POPEN_REPLY   18
-#define USERFILE_PCLOSE	       19
+#define USERFILE_PCLOSE        19
 #define USERFILE_PCLOSE_REPLY  20
-#define USERFILE_RENAME	       21
+#define USERFILE_RENAME        21
 #define USERFILE_RENAME_REPLY  22
 #define USERFILE_SHARED_LOCK   23
 #define USERFILE_SHARED_LOCK_REPLY 24
@@ -176,7 +176,7 @@ Created: Wed Jan 24 20:19:53 1996 ylo
 #define USERFILE_EXCL_LOCK_REPLY 26
 #define USERFILE_UNLOCK        27
 #define USERFILE_UNLOCK_REPLY  28
-#define USERFILE_GET_DES_1_MAGIC_PHRASE	       29
+#define USERFILE_GET_DES_1_MAGIC_PHRASE        29
 #define USERFILE_GET_DES_1_MAGIC_PHRASE_REPLY  30
 
 
@@ -217,7 +217,7 @@ static void userfile_packet_start(int type)
 
 /* Sends a packet that has been constructed in "packet". */
   
-static void userfile_packet_send()
+static void userfile_packet_send(void)
 {
   unsigned char lenbuf[4];
   unsigned int len, offset;
@@ -230,22 +230,22 @@ static void userfile_packet_send()
     {
       bytes = write(userfile_output, lenbuf + offset, len - offset);
       if (bytes <= 0)
-	ssh_fatal("userfile_packet_send: child has died: %s", strerror(errno));
+        ssh_fatal("userfile_packet_send: child has died: %s", strerror(errno));
     }
   
   len = ssh_buffer_len(&packet);
   for (offset = 0; offset < len; offset += bytes)
     {
       bytes = write(userfile_output, ssh_buffer_ptr(&packet) + offset, 
-		    len - offset);
+                    len - offset);
       if (bytes <= 0)
-	ssh_fatal("userfile_packet_send: child has died: %s", strerror(errno));
+        ssh_fatal("userfile_packet_send: child has died: %s", strerror(errno));
     }
 }
 
 /* Reads a packet from the other side.  Returns the packet type. */
 
-static int userfile_read_raw()
+static int userfile_read_raw(void)
 {
   unsigned char buf[512];
   unsigned int len, offset;
@@ -262,11 +262,11 @@ static int userfile_read_raw()
     {
       bytes = read(userfile_input, buf + offset, len - offset);
       if (bytes <= 0)
-	{
-	  if (getuid() == geteuid()) /* presumably child - be quiet */
-	    exit(0);
-	  ssh_fatal("userfile_read_raw: child has died: %s", strerror(errno));
-	}
+        {
+          if (getuid() == geteuid()) /* presumably child - be quiet */
+            exit(0);
+          ssh_fatal("userfile_read_raw: child has died: %s", strerror(errno));
+        }
     }
 
   len = SSH_GET_32BIT(buf);
@@ -278,10 +278,10 @@ static int userfile_read_raw()
     {
       bytes = len - offset;
       if (bytes > sizeof(buf))
-	bytes = sizeof(buf);
+        bytes = sizeof(buf);
       bytes = read(userfile_input, buf, bytes);
       if (bytes <= 0)
-	ssh_fatal("userfile_read_raw: child has died: %s", strerror(errno));
+        ssh_fatal("userfile_read_raw: child has died: %s", strerror(errno));
       ssh_buffer_append(&packet, buf, bytes);
     }
   return buffer_get_char(&packet);
@@ -296,7 +296,7 @@ static void userfile_packet_read(int expected_type)
   type = userfile_read_raw();
   if (type != expected_type)
     ssh_fatal("userfile_read_packet: unexpected packet type: got %d, expected %d",
-	  type, expected_type);
+          type, expected_type);
 }
 
 /* Forks and execs the given command.  Returns a file descriptor for
@@ -323,21 +323,21 @@ int do_popen(const char *command, const char *type)
     { /* Child */
 
       /* Close pipes to the parent; we do not wish to disclose them to a
-	 random user program. */
+         random user program. */
       close(userfile_fromparent);
       close(userfile_toparent);
 
       /* Set up file descriptors. */
       if (type[0] == 'r')
-	{
-	  if (dup2(fds[1], 1) < 0)
-	    perror("dup2 1");
-	}
+        {
+          if (dup2(fds[1], 1) < 0)
+            perror("dup2 1");
+        }
       else
-	{
-	  if (dup2(fds[0], 0) < 0)
-	    perror("dup2 0");
-	}
+        {
+          if (dup2(fds[0], 0) < 0)
+            perror("dup2 0");
+        }
       close(fds[0]);
       close(fds[1]);
 
@@ -351,20 +351,20 @@ int do_popen(const char *command, const char *type)
       /* Prune environment to remove any potentially dangerous variables. */
       i = 0;
       for (j = 0; environ[j] && i < sizeof(env)/sizeof(env[0]) - 1; j++)
-	if (strncmp(environ[j], "HOME=", 5) == 0 ||
-	    strncmp(environ[j], "USER=", 5) == 0 ||
-	    strncmp(environ[j], "HOME=", 5) == 0 ||
-	    strncmp(environ[j], "PATH=", 5) == 0 ||
-	    strncmp(environ[j], "LOGNAME=", 8) == 0 ||
-	    strncmp(environ[j], "TZ=", 3) == 0 ||
-	    strncmp(environ[j], "MAIL=", 5) == 0 ||
-	    strncmp(environ[j], "SHELL=", 6) == 0 ||
-	    strncmp(environ[j], "TERM=", 5) == 0 ||
-	    strncmp(environ[j], "DISPLAY=", 8) == 0 ||
-	    strncmp(environ[j], "PRINTER=", 8) == 0 ||
-	    strncmp(environ[j], "XAUTHORITY=", 11) == 0 ||
-	    strncmp(environ[j], "TERMCAP=", 8) == 0)
-	  env[i++] = environ[j];
+        if (strncmp(environ[j], "HOME=", 5) == 0 ||
+            strncmp(environ[j], "USER=", 5) == 0 ||
+            strncmp(environ[j], "HOME=", 5) == 0 ||
+            strncmp(environ[j], "PATH=", 5) == 0 ||
+            strncmp(environ[j], "LOGNAME=", 8) == 0 ||
+            strncmp(environ[j], "TZ=", 3) == 0 ||
+            strncmp(environ[j], "MAIL=", 5) == 0 ||
+            strncmp(environ[j], "SHELL=", 6) == 0 ||
+            strncmp(environ[j], "TERM=", 5) == 0 ||
+            strncmp(environ[j], "DISPLAY=", 8) == 0 ||
+            strncmp(environ[j], "PRINTER=", 8) == 0 ||
+            strncmp(environ[j], "XAUTHORITY=", 11) == 0 ||
+            strncmp(environ[j], "TERMCAP=", 8) == 0)
+          env[i++] = environ[j];
       env[i] = NULL;
 
       execve("/bin/sh", args, env);
@@ -386,7 +386,7 @@ int do_popen(const char *command, const char *type)
 
 /* This function is the main loop of the child.  This never returns. */
 
-static void userfile_child_server()
+static void userfile_child_server(void)
 {
   int type, handle, ret, ret2;
   unsigned int max_bytes, flags, whence;
@@ -401,213 +401,213 @@ static void userfile_child_server()
     {
       type = userfile_read_raw();
       switch (type)
-	{
-	case USERFILE_OPEN:
-	  path = buffer_get_uint32_string(&packet, NULL);
-	  flags = buffer_get_int(&packet);
-	  mode = buffer_get_int(&packet);
+        {
+        case USERFILE_OPEN:
+          path = buffer_get_uint32_string(&packet, NULL);
+          flags = buffer_get_int(&packet);
+          mode = buffer_get_int(&packet);
 
-	  ret = open(path, flags, mode);
+          ret = open(path, flags, mode);
 
-	  userfile_packet_start(USERFILE_OPEN_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_OPEN_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(path);
-	  break;
+          ssh_xfree(path);
+          break;
 
-	case USERFILE_READ:
-	  handle = buffer_get_int(&packet);
-	  max_bytes = buffer_get_int(&packet);
+        case USERFILE_READ:
+          handle = buffer_get_int(&packet);
+          max_bytes = buffer_get_int(&packet);
 
-	  if (max_bytes >= sizeof(buf))
-	    max_bytes = sizeof(buf);
-	  ret = read(handle, buf, max_bytes);
-	  if (ret < 0)
-	    ret = 0;
+          if (max_bytes >= sizeof(buf))
+            max_bytes = sizeof(buf);
+          ret = read(handle, buf, max_bytes);
+          if (ret < 0)
+            ret = 0;
 
-	  userfile_packet_start(USERFILE_READ_REPLY);
-	  buffer_put_uint32_string(&packet, buf, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_READ_REPLY);
+          buffer_put_uint32_string(&packet, buf, ret);
+          userfile_packet_send();
 
-	  break;
-	  
-	case USERFILE_WRITE:
-	  handle = buffer_get_int(&packet);
-	  cp = buffer_get_uint32_string(&packet, &len);
+          break;
+          
+        case USERFILE_WRITE:
+          handle = buffer_get_int(&packet);
+          cp = buffer_get_uint32_string(&packet, &len);
 
-	  ret = write(handle, cp, len);
+          ret = write(handle, cp, len);
 
-	  userfile_packet_start(USERFILE_WRITE_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_WRITE_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(cp);
-	  break;
+          ssh_xfree(cp);
+          break;
 
-	case USERFILE_CLOSE:
-	  handle = buffer_get_int(&packet);
+        case USERFILE_CLOSE:
+          handle = buffer_get_int(&packet);
 
-	  ret = close(handle);
+          ret = close(handle);
 
-	  userfile_packet_start(USERFILE_CLOSE_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_CLOSE_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  break;
+          break;
 
-	case USERFILE_LSEEK:
-	  handle = buffer_get_int(&packet);
-	  offset = buffer_get_int(&packet);
-	  whence = buffer_get_int(&packet);
+        case USERFILE_LSEEK:
+          handle = buffer_get_int(&packet);
+          offset = buffer_get_int(&packet);
+          whence = buffer_get_int(&packet);
 
-	  ret = lseek(handle, offset, whence);
+          ret = lseek(handle, offset, whence);
 
-	  userfile_packet_start(USERFILE_LSEEK_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_LSEEK_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  break;
+          break;
 
-	case USERFILE_MKDIR:
-	  path = buffer_get_uint32_string(&packet, NULL);
-	  mode = buffer_get_int(&packet);
+        case USERFILE_MKDIR:
+          path = buffer_get_uint32_string(&packet, NULL);
+          mode = buffer_get_int(&packet);
 
-	  ret = mkdir(path, mode);
+          ret = mkdir(path, mode);
 
-	  userfile_packet_start(USERFILE_MKDIR_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_MKDIR_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(path);
-	  break;
+          ssh_xfree(path);
+          break;
 
-	case USERFILE_STAT:
-	  path = buffer_get_uint32_string(&packet, NULL);
+        case USERFILE_STAT:
+          path = buffer_get_uint32_string(&packet, NULL);
 
-	  ret = stat(path, &st);
+          ret = stat(path, &st);
 
-	  userfile_packet_start(USERFILE_STAT_REPLY);
-	  buffer_put_int(&packet, ret);
-	  ssh_buffer_append(&packet, (void *)&st, sizeof(st));
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_STAT_REPLY);
+          buffer_put_int(&packet, ret);
+          ssh_buffer_append(&packet, (void *)&st, sizeof(st));
+          userfile_packet_send();
 
-	  ssh_xfree(path);
-	  break;
-	  
-	case USERFILE_REMOVE:
-	  path = buffer_get_uint32_string(&packet, NULL);
+          ssh_xfree(path);
+          break;
+          
+        case USERFILE_REMOVE:
+          path = buffer_get_uint32_string(&packet, NULL);
 
-	  ret = remove(path);
+          ret = remove(path);
 
-	  userfile_packet_start(USERFILE_REMOVE_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_REMOVE_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(path);
-	  break;
+          ssh_xfree(path);
+          break;
 
-	case USERFILE_RENAME:
-	  path = buffer_get_uint32_string(&packet, NULL);
-	  newpath = buffer_get_uint32_string(&packet, NULL);
+        case USERFILE_RENAME:
+          path = buffer_get_uint32_string(&packet, NULL);
+          newpath = buffer_get_uint32_string(&packet, NULL);
 
-	  ret = rename(path, newpath);
+          ret = rename(path, newpath);
 
-	  userfile_packet_start(USERFILE_RENAME_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_RENAME_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(path);
-	  ssh_xfree(newpath);
-	  break;
-	 
-	case USERFILE_SHARED_LOCK:
-	  handle = buffer_get_int(&packet);
-	  offset = (off_t)buffer_get_int(&packet);
-	  len = buffer_get_int(&packet);
+          ssh_xfree(path);
+          ssh_xfree(newpath);
+          break;
+         
+        case USERFILE_SHARED_LOCK:
+          handle = buffer_get_int(&packet);
+          offset = (off_t)buffer_get_int(&packet);
+          len = buffer_get_int(&packet);
 
-	  ret = filelock_lock_shared(handle, offset, len);
+          ret = filelock_lock_shared(handle, offset, len);
 
-	  userfile_packet_start(USERFILE_SHARED_LOCK_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_SHARED_LOCK_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  break;
-	  
-	case USERFILE_EXCL_LOCK:
-	  handle = buffer_get_int(&packet);
-	  offset = (off_t)buffer_get_int(&packet);
-	  len = buffer_get_int(&packet);
+          break;
+          
+        case USERFILE_EXCL_LOCK:
+          handle = buffer_get_int(&packet);
+          offset = (off_t)buffer_get_int(&packet);
+          len = buffer_get_int(&packet);
 
-	  ret = filelock_lock_exclusive(handle, offset, len);
+          ret = filelock_lock_exclusive(handle, offset, len);
 
-	  userfile_packet_start(USERFILE_EXCL_LOCK_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_EXCL_LOCK_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  break;
-	  
-	case USERFILE_UNLOCK:
-	  handle = buffer_get_int(&packet);
-	  offset = (off_t)buffer_get_int(&packet);
-	  len = buffer_get_int(&packet);
+          break;
+          
+        case USERFILE_UNLOCK:
+          handle = buffer_get_int(&packet);
+          offset = (off_t)buffer_get_int(&packet);
+          len = buffer_get_int(&packet);
 
-	  ret = filelock_unlock(handle, offset, len);
+          ret = filelock_unlock(handle, offset, len);
 
-	  userfile_packet_start(USERFILE_UNLOCK_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_UNLOCK_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  break;
-	  
-	case USERFILE_POPEN:
-	  command = buffer_get_uint32_string(&packet, NULL);
-	  cp = buffer_get_uint32_string(&packet, NULL);
+          break;
+          
+        case USERFILE_POPEN:
+          command = buffer_get_uint32_string(&packet, NULL);
+          cp = buffer_get_uint32_string(&packet, NULL);
 
-	  ret = do_popen(command, cp);
+          ret = do_popen(command, cp);
 
-	  userfile_packet_start(USERFILE_POPEN_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
+          userfile_packet_start(USERFILE_POPEN_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
 
-	  ssh_xfree(command);
-	  ssh_xfree(cp);
-	  break;
+          ssh_xfree(command);
+          ssh_xfree(cp);
+          break;
 
-	case USERFILE_PCLOSE:
-	  handle = buffer_get_int(&packet);
+        case USERFILE_PCLOSE:
+          handle = buffer_get_int(&packet);
 
-	  ret = close(handle);
-	  ret2 = wait(NULL);
-	  if (ret >= 0)
-	    ret = ret2;
+          ret = close(handle);
+          ret2 = wait(NULL);
+          if (ret >= 0)
+            ret = ret2;
 
-	  userfile_packet_start(USERFILE_PCLOSE_REPLY);
-	  buffer_put_int(&packet, ret);
-	  userfile_packet_send();
-	  break;
+          userfile_packet_start(USERFILE_PCLOSE_REPLY);
+          buffer_put_int(&packet, ret);
+          userfile_packet_send();
+          break;
 
-	case USERFILE_GET_DES_1_MAGIC_PHRASE:
-	  {
-	    char *buf = NULL;
+        case USERFILE_GET_DES_1_MAGIC_PHRASE:
+          {
+            char *buf = NULL;
 #ifdef SECURE_RPC
-	    buf = userfile_get_des_1_magic_phrase(geteuid());
+            buf = userfile_get_des_1_magic_phrase(geteuid());
 #endif
-	    userfile_packet_start(USERFILE_GET_DES_1_MAGIC_PHRASE_REPLY);
-	    if (buf == NULL)
-	      buffer_put_uint32_string(&packet, "", 0);
-	    else
-	      {
-		buffer_put_uint32_string(&packet, buf, strlen(buf));
-		memset(buf, 0, strlen(buf));
-	      }
-	    userfile_packet_send();
-	  }
-	  break;
+            userfile_packet_start(USERFILE_GET_DES_1_MAGIC_PHRASE_REPLY);
+            if (buf == NULL)
+              buffer_put_uint32_string(&packet, "", 0);
+            else
+              {
+                buffer_put_uint32_string(&packet, buf, strlen(buf));
+                memset(buf, 0, strlen(buf));
+              }
+            userfile_packet_send();
+          }
+          break;
 
-	default:
-	  ssh_fatal("userfile_child_server: packet type %d", type);
-	}
+        default:
+          ssh_fatal("userfile_child_server: packet type %d", type);
+        }
     }
 }
 
@@ -618,7 +618,7 @@ static void userfile_child_server()
    user's uid.  The callback may be NULL. */
 
 void userfile_init(const char *username, uid_t uid, gid_t gid,
-		   void (*cleanup_callback)(void *), void *context)
+                   void (*cleanup_callback)(void *), void *context)
 {
   int fds[2], pid;
 
@@ -672,20 +672,20 @@ void userfile_init(const char *username, uid_t uid, gid_t gid,
       struct passwd * pw = getpwuid(uid);
       login_cap_t * lc = login_getuserclass(pw);
       if (setusercontext(lc, pw, uid,
-			 LOGIN_SETALL & ~(LOGIN_SETLOGIN | LOGIN_SETPATH |
-					  LOGIN_SETENV)) < 0)
-	ssh_fatal("setusercontext: %s", strerror(errno));
+                         LOGIN_SETALL & ~(LOGIN_SETLOGIN | LOGIN_SETPATH |
+                                          LOGIN_SETENV)) < 0)
+        ssh_fatal("setusercontext: %s", strerror(errno));
 #else
       if (setgid(gid) < 0)
-	ssh_fatal("setgid: %s", strerror(errno));
+        ssh_fatal("setgid: %s", strerror(errno));
 
 #ifdef HAVE_INITGROUPS
       if (initgroups((char *) username, gid) < 0)
-	ssh_fatal("initgroups: %s", strerror(errno));
+        ssh_fatal("initgroups: %s", strerror(errno));
 #endif /* HAVE_INITGROUPS */
 
       if (setuid(uid) < 0)
-	ssh_fatal("setuid: %s", strerror(errno));
+        ssh_fatal("setuid: %s", strerror(errno));
 #endif /* HAVE_LOGIN_CAP_H */
     }
 
@@ -696,7 +696,7 @@ void userfile_init(const char *username, uid_t uid, gid_t gid,
 /* Closes any open pipes held by userfile.  This should be called
    after a fork while the userfile is open. */
 
-void userfile_close_pipes()
+void userfile_close_pipes(void)
 {
   if (!userfile_initialized)
     return;
@@ -708,7 +708,7 @@ void userfile_close_pipes()
 /* Stops reading files as an ordinary user.  It is not an error to call
    this even if the system is not initialized. */
 
-void userfile_uninit()
+void userfile_uninit(void)
 {
   int status;
 
@@ -766,19 +766,19 @@ UserFile userfile_open(uid_t uid, const char *path, int flags, mode_t mode)
     {
       handle = open(path, flags, mode);
       if (handle < 0)
-	return NULL;
+        return NULL;
       return userfile_make_handle(USERFILE_LOCAL, handle);
     }
 
   if (!userfile_initialized)
     ssh_fatal("userfile_open: using non-current uid but not initialized "
-	      "(uid=%d, path=%.50s)",
-	      (int)uid, path);
+              "(uid=%d, path=%.50s)",
+              (int)uid, path);
   
   if (uid != userfile_uid)
     ssh_fatal("userfile_open: uid not current and not that of child: "
-	      "uid=%d, path=%.50s",
-	      (int)uid, path);
+              "uid=%d, path=%.50s",
+              (int)uid, path);
 
   userfile_packet_start(USERFILE_OPEN);
   buffer_put_uint32_string(&packet, path, strlen(path));
@@ -859,7 +859,7 @@ static int userfile_fill(UserFile uf)
     case USERFILE_LOCAL:
       ret = read(uf->handle, uf->buf, sizeof(uf->buf));
       if (ret <= 0)
-	return 0;
+        return 0;
       uf->buf_first = 0;
       uf->buf_last = ret;
       break;
@@ -873,11 +873,11 @@ static int userfile_fill(UserFile uf)
       userfile_packet_read(USERFILE_READ_REPLY);
       cp = buffer_get_uint32_string(&packet, &len);
       if (len > sizeof(uf->buf))
-	ssh_fatal("userfile_fill: got more than data than requested");
+        ssh_fatal("userfile_fill: got more than data than requested");
       memcpy(uf->buf, cp, len);
       ssh_xfree(cp);
       if (len == 0)
-	return 0;
+        return 0;
       uf->buf_first = 0;
       uf->buf_last = len;
       break;
@@ -897,10 +897,10 @@ int userfile_getc(UserFile uf)
   if (uf->buf_first >= uf->buf_last)
     {
       if (!userfile_fill(uf))
-	return -1;
+        return -1;
       
       if (uf->buf_first >= uf->buf_last)
-	ssh_fatal("userfile_getc/fill error");
+        ssh_fatal("userfile_getc/fill error");
     }
   
   return uf->buf[uf->buf_first++];
@@ -921,7 +921,7 @@ int userfile_read(UserFile uf, void *buf, unsigned int len)
     {
       ch = userfile_getc(uf);
       if (ch == -1)
-	break;
+        break;
       ucp[i] = ch;
     }
 
@@ -945,24 +945,24 @@ int userfile_write(UserFile uf, const void *buf, unsigned int len)
     case USERFILE_REMOTE:
       ucp = buf;
       for (offset = 0; offset < len; )
-	{
-	  chunk_len = len - offset;
-	  if (chunk_len > 16000)
-	    chunk_len = 16000;
-	  
-	  userfile_packet_start(USERFILE_WRITE);
-	  buffer_put_int(&packet, uf->handle);
-	  buffer_put_uint32_string(&packet, ucp + offset, chunk_len);
-	  userfile_packet_send();
-	  
-	  userfile_packet_read(USERFILE_WRITE_REPLY);
-	  ret = buffer_get_int(&packet);
-	  if (ret < 0)
-	    return -1;
-	  offset += ret;
-	  if (ret != chunk_len)
-	    break;
-	}
+        {
+          chunk_len = len - offset;
+          if (chunk_len > 16000)
+            chunk_len = 16000;
+          
+          userfile_packet_start(USERFILE_WRITE);
+          buffer_put_int(&packet, uf->handle);
+          buffer_put_uint32_string(&packet, ucp + offset, chunk_len);
+          userfile_packet_send();
+          
+          userfile_packet_read(USERFILE_WRITE_REPLY);
+          ret = buffer_get_int(&packet);
+          if (ret < 0)
+            return -1;
+          offset += ret;
+          if (ret != chunk_len)
+            break;
+        }
       return offset;
 
     default:
@@ -989,10 +989,10 @@ char *userfile_gets(char *buf, unsigned int size, UserFile uf)
     {
       ch = userfile_getc(uf);
       if (ch == -1)
-	break;
+        break;
       buf[i++] = ch;
       if (ch == '\n')
-	break;
+        break;
     }
   if (i == 0)
     return NULL;
@@ -1211,17 +1211,17 @@ UserFile userfile_popen(uid_t uid, const char *command, const char *type)
     {
       handle = do_popen(command, type);
       if (handle < 0)
-	return NULL;
+        return NULL;
       return userfile_make_handle(USERFILE_LOCAL, handle);
     }
 
   if (!userfile_initialized)
     ssh_fatal("userfile_popen: using non-current uid but not initialized (uid=%d)",
-	  (int)uid);
+          (int)uid);
   
   if (uid != userfile_uid)
     ssh_fatal("userfile_popen: uid not current and not that of child: uid=%d",
-	  (int)uid);
+          (int)uid);
 
   userfile_packet_start(USERFILE_POPEN);
   buffer_put_uint32_string(&packet, command, strlen(command));
@@ -1248,7 +1248,7 @@ int userfile_pclose(UserFile uf)
       ret = close(uf->handle);
       ret2 = wait(NULL);
       if (ret >= 0)
-	ret = ret2;
+        ret = ret2;
       ssh_xfree(uf);
       return ret;
 
@@ -1286,16 +1286,16 @@ char *userfile_get_des_1_magic_phrase(uid_t uid)
       snprintf(buf, sizeof(buf), "ssh.%04X", geteuid());
       memcpy(block.c, buf, sizeof(block.c));
       if (getnetname(buf))
-	{
-	  if (key_encryptsession(buf, &block) == 0)
-	    {
-	      snprintf(buf, sizeof(buf), "%08X%08X", ntohl(block.key.high),
-		       ntohl(block.key.low));
-	      memset(block.c, 0, sizeof(block.c));
-	      phrase = ssh_xstrdup(buf);
-	      memset(buf, 0, sizeof(buf));
-	    }
-	}
+        {
+          if (key_encryptsession(buf, &block) == 0)
+            {
+              snprintf(buf, sizeof(buf), "%08X%08X", ntohl(block.key.high),
+                       ntohl(block.key.low));
+              memset(block.c, 0, sizeof(block.c));
+              phrase = ssh_xstrdup(buf);
+              memset(buf, 0, sizeof(buf));
+            }
+        }
       return phrase;
     }
   
